@@ -16,17 +16,20 @@ bot.
 """
 
 import logging
-import json
 from telegram.ext import Updater, CommandHandler, MessageHandler, Filters
-from telegram.update import Update
 
 # Enable logging
 from LinuxServerStatsTelegramBot.DI import DI
+from LinuxServerStatsTelegramBot.commmand.CpuStats import CpuStats
 from LinuxServerStatsTelegramBot.commmand.CronStats import CronStats
 from LinuxServerStatsTelegramBot.commmand.DateAndLocation import DateAndLocation
 from LinuxServerStatsTelegramBot.commmand.DiskStats import DiskStats
 from LinuxServerStatsTelegramBot.commmand.DockerStats import DockerStats
 from LinuxServerStatsTelegramBot.commmand.MemoryStats import MemoryStats
+from LinuxServerStatsTelegramBot.commmand.CleanMemory import CleanMemory
+from LinuxServerStatsTelegramBot.commmand.RebootApp import RebootApp
+from LinuxServerStatsTelegramBot.commmand.RebootContainer import RebootContainer
+from LinuxServerStatsTelegramBot.commmand.ServersHealth import ServersHealth
 from LinuxServerStatsTelegramBot.core.Invoker import Invoker
 from LinuxServerStatsTelegramBot.sender.TelegramSender import TelegramSender
 
@@ -51,12 +54,60 @@ def help(update, context):
     /dateandlocation    : Create a image with Server Date and location
     /disk               : Create a image with Disks stats
     /docker             : Create a image with Docker stats
+    /cpu                : Create a image with CPU stats
     /memory             : Create a image with Server Memory stats
     /reports            : Create a zip containing all reports as text files 
+    /cleanmemory        : Execute a command to clear the cache and garbage memory 
+    /servershealth      : Create a image with the servers health status
+    /rebootapp          : Reboot a application managed by docker containers
+    /rebootcontainer    : Reboot a docker container
+    
     """
     update.message.reply_text(help_text)
 
 
+def rebootapp(update, context):
+    if len(context.args) > 0:
+        application_name = context.args[0]
+        update.message.reply_text("Rebooting application...")
+        chat_id = update.message.from_user.id
+        DI.set_sender_temporarily(TelegramSender(str(chat_id)))
+        Invoker.send_data_as_image(RebootApp(application_name))
+        update.message.reply_text("Application rebooted...")
+        DI.set_original_sender()
+    else:
+        update.message.reply_text(RebootApp().missing_container_name())
+
+
+def rebootcontainer(update, context):
+    if len(context.args) > 0:
+        container_name = context.args[0]
+        update.message.reply_text("Rebooting container...")
+        chat_id = update.message.from_user.id
+        DI.set_sender_temporarily(TelegramSender(str(chat_id)))
+        Invoker.send_data_as_image(RebootContainer(container_name))
+        update.message.reply_text("Container rebooted...")
+        DI.set_original_sender()
+    else:
+        update.message.reply_text(RebootContainer().missing_container_name())
+
+
+def cleanmemory(update, context):
+    update.message.reply_text("Executing Memory Clean...")
+    chat_id = update.message.from_user.id
+    DI.set_sender_temporarily(TelegramSender(str(chat_id)))
+    Invoker.send_data_as_image(CleanMemory())
+    DI.set_original_sender()
+
+
+def servershealth(update, context):
+    update.message.reply_text("Processing Servers Health stats...")
+    chat_id = update.message.from_user.id
+    DI.set_sender_temporarily(TelegramSender(str(chat_id)))
+    Invoker.send_data_as_image(ServersHealth())
+    DI.set_original_sender()
+
+
 def memory(update, context):
     """Send a message when the command /help is issued."""
     update.message.reply_text("Processing Memory stats...")
@@ -66,6 +117,15 @@ def memory(update, context):
     DI.set_original_sender()
 
 
+def cpu(update, context):
+    """Send a message when the command /help is issued."""
+    update.message.reply_text("Processing CPU stats...")
+    chat_id = update.message.from_user.id
+    DI.set_sender_temporarily(TelegramSender(str(chat_id)))
+    Invoker.send_data_as_image(CpuStats())
+    DI.set_original_sender()
+
+
 def dateandlocation(update, context):
     """Send a message when the command /help is issued."""
     # u.message.reply_photo()
@@ -137,11 +197,16 @@ def main():
     dp.add_handler(CommandHandler("start", start))
     dp.add_handler(CommandHandler("help", help))
     dp.add_handler(CommandHandler("memory", memory))
+    dp.add_handler(CommandHandler("cpu", cpu))
     dp.add_handler(CommandHandler("dateandlocation", dateandlocation))
     dp.add_handler(CommandHandler("cron", cron))
     dp.add_handler(CommandHandler("disk", disk))
     dp.add_handler(CommandHandler("docker", docker))
     dp.add_handler(CommandHandler("reports", reports))
+    dp.add_handler(CommandHandler("cleanmemory", cleanmemory))
+    dp.add_handler(CommandHandler("servershealth", servershealth))
+    dp.add_handler(CommandHandler("rebootapp", rebootapp))
+    dp.add_handler(CommandHandler("rebootcontainer", rebootcontainer))
 
     # on noncommand i.e message - echo the message on Telegram
     dp.add_handler(MessageHandler(Filters.text, echo))
