@@ -13,6 +13,7 @@ from LinuxServerStatsTelegramBot.commmand.MemoryStats import MemoryStats
 from LinuxServerStatsTelegramBot.commmand.DateAndLocation import DateAndLocation
 from LinuxServerStatsTelegramBot.commmand.ServersHealth import ServersHealth
 
+
 class Invoker:
     @staticmethod
     def send_server_stats_as_images():
@@ -27,8 +28,7 @@ class Invoker:
 
     @staticmethod
     def send_server_stats_as_text():
-        commands = [DateAndLocation(), MemoryStats(), CpuStats(), DiskStats(),
-                    DockerStats(), CronStats(), ServersHealth()]
+        commands = [DateAndLocation(), MemoryStats(), CpuStats(), DiskStats(), DockerStats(), CronStats(), ServersHealth()]
         Invoker.zip_and_send(commands)
 
     @staticmethod
@@ -60,6 +60,10 @@ class Invoker:
         ConvertTextToImage(data=data, image_path=image_path).execute()
         sender.send_image(image_path=image_path)
 
+    @staticmethod
+    def only_execute(command: Command):
+        command.execute()
+
     @staticmethod
     def send_sticker():
         sticker_path = SendProgrammerBeeSticker().execute()
